@@ -1,3 +1,6 @@
+import re
+
+
 def _symbols_request_info() -> dict:
     return {
         "extension": f"ref-data/symbols"
@@ -5,11 +8,10 @@ def _symbols_request_info() -> dict:
 
 
 def _historical_prices_request_info(*symbol: str, **kwargs) -> dict:
-    request_info = {
-        'range': '1m',
-        'sort': 'asc'
-    }
-    request_info.update(kwargs)
+    # clean _from since it's a special word in python
+    clean_kwargs = {re.sub('^_', '', k): v for k, v in kwargs.items()}
+    request_info = {'sort': 'asc'}
+    request_info.update(clean_kwargs)
 
     if len(symbol) > 1:
         request_info.update({
