@@ -8,7 +8,8 @@ from algora.api.service.admin.__util import (
     _get_groups_request_info, _get_group_members_request_info, _add_group_to_user_request_info,
     _delete_group_from_user_request_info, _get_roles_request_info, _get_roles_for_user_request_info,
     _add_role_mapping_to_user_request_info, _execute_actions_email_request_info, _delete_offline_token_request_info,
-    _update_offline_token_request_info, _create_offline_token_request_info, _get_offline_token_request_info
+    _update_offline_token_request_info, _create_offline_token_request_info, _get_offline_token_request_info,
+    _get_user_count_request_info
 )
 from algora.common.decorators import async_data_request
 from algora.common.function import no_transform
@@ -30,14 +31,26 @@ async def async_get_client_id():
 
 
 @async_data_request
-async def async_get_users(limit: int = 500):
+async def async_get_users(limit: int = 500, page_offset: int = 0):
     """
     Asynchronously get all users.
 
     Returns:
         List of user response.
     """
-    request_info = _get_users_request_info(limit)
+    request_info = _get_users_request_info(limit, page_offset)
+    return await __async_get_request(**request_info)
+
+
+@async_data_request(transformer=no_transform)
+async def async_get_user_count():
+    """
+    Get the total number of users.
+
+    Returns:
+        The total number of users.
+    """
+    request_info = _get_user_count_request_info()
     return await __async_get_request(**request_info)
 
 
