@@ -1,5 +1,3 @@
-import json
-
 from algora.api.service.permission.model import PermissionRequest
 
 
@@ -24,14 +22,14 @@ def _get_permissions_by_resource_id_request_info(resource_id: str) -> dict:
 def _create_permission_request_info(request: PermissionRequest) -> dict:
     return {
         'endpoint': f"config/permission",
-        'json': json.loads(request.json())
+        'json': request.request_dict()
     }
 
 
 def _update_permission_request_info(id: str, request: PermissionRequest) -> dict:
     return {
         'endpoint': f"config/permission/{id}",
-        'json': json.loads(request.json())
+        'json': request.request_dict()
     }
 
 
